@@ -1,19 +1,292 @@
 package Module::Format::Module;
-
+$Module::Format::Module::VERSION = '0.0.8';
 use warnings;
 use strict;
 
+
+sub _new
+{
+    my $class = shift;
+    my $self = bless {}, $class;
+    $self->_init(@_);
+    return $self;
+}
+
+sub _components
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_components} = shift;
+    }
+    return $self->{_components};
+}
+
+sub _init
+{
+    my ( $self, $args ) = @_;
+
+    $self->_components( [ @{ $args->{_components} } ] );
+
+    return;
+}
+
+
+sub from_components
+{
+    my ( $class, $args ) = @_;
+
+    return $class->_new( { _components => [ @{ $args->{components} } ] } );
+}
+
+
+my $dash_re  = qr{(?:\w+-)*\w+};
+my $colon_re = qr{(?:\w+::)*\w+};
+
+my @formats_by_priority = (
+    {
+        name  => 'rpm_dash',
+        regex => qr{\Aperl-$dash_re\z},
+        input => sub {
+            my ( $class, $value ) = @_;
+
+            if ( $value !~ s{\Aperl-}{} )
+            {
+                die "rpm_dash value does not start with the 'perl-' prefix.";
+            }
+
+            return $class->_calc_components_from_string(
+                { format => 'dash', value => $value } );
+        },
+        format => sub {
+            my ($self) = @_;
+
+            return 'perl-' . $self->format_as('dash');
+        },
+    },
+    {
+        name  => 'rpm_colon',
+        regex => qr{\Aperl\($colon_re\)\z},
+        input => sub {
+            my ( $class, $value ) = @_;
+
+            if ( $value !~ m{\Aperl\(((?:\w+::)*\w+)\)\z} )
+            {
+                die "Improper value for rpm_colon";
+            }
+
+            return $class->_calc_components_from_string(
+                { format => 'colon', value => $1 } );
+        },
+        format => sub {
+            my ($self) = @_;
+
+            return 'perl(' . $self->format_as('colon') . ')';
+        },
+    },
+    {
+        name  => 'colon',
+        regex => qr{\A$colon_re\z},
+        input => sub {
+            my ( $class, $value ) = @_;
+            return [ split( /::/, $value, -1 ) ];
+        },
+        format => sub {
+            my ($self) = @_;
+
+            return join( '::', @{ $self->_components() } );
+        },
+    },
+    {
+        name  => 'dash',
+        regex => qr{\A$dash_re\z},
+        input => sub {
+            my ( $class, $value ) = @_;
+            return [ split( /-/, $value, -1 ) ];
+        },
+        format => sub {
+            my ($self) = @_;
+
+            return join( '-', @{ $self->_components() } );
+        },
+    },
+    {
+        name  => 'unix',
+        regex => qr{\A(?:\w+/)*\w+\.pm\z},
+        input => sub {
+            my ( $class, $value ) = @_;
+
+            if ( $value !~ s{\.pm\z}{} )
+            {
+                die "Cannot find a .pm suffix in the 'unix' format.";
+            }
+
+            return [ split( m{/}, $value, -1 ) ];
+        },
+        format => sub {
+            my ($self) = @_;
+
+            return join( '/', @{ $self->_components() } ) . '.pm';
+        },
+    },
+    {
+        name   => 'debian',
+        format => sub {
+            my ($self) = @_;
+
+            return 'lib' . lc( $self->format_as('dash') ) . '-perl';
+        },
+    },
+);
+
+my %formats = ( map { $_->{name} => $_ } @formats_by_priority );
+
+sub _calc_components_from_string
+{
+    my ( $class, $args ) = @_;
+
+    my $format = $args->{format};
+    my $value  = $args->{value};
+
+    if ( exists( $formats{$format} ) )
+    {
+        if ( my $handler = $formats{$format}->{'input'} )
+        {
+            return $class->$handler($value);
+        }
+        else
+        {
+            die "Format $format is output-only!";
+        }
+    }
+    else
+    {
+        die "Unknown format '$format'!";
+    }
+}
+
+sub from
+{
+    my ( $class, $args ) = @_;
+
+    my $format = $args->{format};
+    my $value  = $args->{value};
+
+    return $class->_new(
+        {
+            _components => $class->_calc_components_from_string($args)
+        }
+    );
+}
+
+
+sub get_components_list
+{
+    my $self = shift;
+
+    return [ @{ $self->_components() } ];
+}
+
+
+sub format_as
+{
+    my ( $self, $format ) = @_;
+
+    if ( exists( $formats{$format} ) )
+    {
+        my $handler = $formats{$format}->{'format'};
+        return $self->$handler();
+    }
+    else
+    {
+        die "Unknown format '$format';";
+    }
+
+    return;
+}
+
+
+sub clone
+{
+    my $self = shift;
+
+    return
+        ref($self)
+        ->from_components( { components => $self->get_components_list() } );
+}
+
+
+sub _all
+{
+    my ( $cb, $l ) = @_;
+
+    foreach (@$l)
+    {
+        if ( not $cb->($_) )
+        {
+            return;
+        }
+    }
+
+    return 1;
+}
+
+sub is_sane
+{
+    my $self = shift;
+
+    return _all( sub { m{\A\w+\z}; }, $self->_components() );
+}
+
+
+sub from_guess
+{
+    my ( $class, $args ) = @_;
+
+    my $dummy_format_string;
+
+    my $string = $args->{value};
+    my $out_format_ref = ( $args->{format_ref} || ( \$dummy_format_string ) );
+
+    # TODO : After the previous line the indentation in vim is reset to the
+    # first column.
+
+    foreach my $format_record (@formats_by_priority)
+    {
+        if ( my $regex = $format_record->{regex} )
+        {
+            if ( $string =~ $regex )
+            {
+                my $format_id = $format_record->{name};
+
+                ${$out_format_ref} = $format_id;
+
+                return $class->from(
+                    { value => $string, format => $format_id, } );
+            }
+        }
+    }
+
+    die "Could not guess the format of the value '$string'!";
+}
+
+
+1;    # End of Module::Format::Module
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Module::Format::Module - encapsulates a single Perl module.
 
 =head1 VERSION
 
-Version 0.0.7
-
-=cut
-
-our $VERSION = '0.0.7';
+version 0.0.8
 
 =head1 SYNOPSIS
 
@@ -69,35 +342,9 @@ our $VERSION = '0.0.7';
     # Prints "libxml-rss-perl"
     print $module->format_as('debian'), "\n";
 
-=cut
+=head1 VERSION
 
-sub _new
-{
-    my $class = shift;
-    my $self = bless {}, $class;
-    $self->_init(@_);
-    return $self;
-}
-
-sub _components
-{
-    my $self = shift;
-
-    if (@_)
-    {
-        $self->{_components} = shift;
-    }
-    return $self->{_components};
-}
-
-sub _init
-{
-    my ($self, $args) = @_;
-
-    $self->_components([ @{ $args->{_components} } ]);
-
-    return;
-}
+version 0.0.8
 
 =head1 FUNCTIONS
 
@@ -112,15 +359,6 @@ individual components of the module. For example:
         }
     );
 
-=cut
-
-sub from_components
-{
-    my ($class, $args) = @_;
-
-    return $class->_new({_components => [@{$args->{components}}]});
-}
-
 =head2 my $module = Module::Format::Module->from({format => $format, value => $string});
 
 Construct a Module::Format::Module object from the given format $format
@@ -163,233 +401,25 @@ C<libcatalyst-plugin-authentication-perl> . Output only.
 
 =back
 
-=cut
-
-my $dash_re = qr{(?:\w+-)*\w+};
-my $colon_re = qr{(?:\w+::)*\w+};
-
-my @formats_by_priority =
-(
-    {
-        name => 'rpm_dash',
-        regex => qr{\Aperl-$dash_re\z},
-        input =>
-        sub {
-            my ($class, $value) = @_;
-
-            if ($value !~ s{\Aperl-}{})
-            {
-                die "rpm_dash value does not start with the 'perl-' prefix.";
-            }
-
-            return $class->_calc_components_from_string(
-                {format => 'dash', value => $value}
-            );
-        },
-        format => sub {
-            my ($self) = @_;
-
-            return 'perl-' . $self->format_as('dash');
-        },
-    },
-    {
-        name => 'rpm_colon',
-        regex => qr{\Aperl\($colon_re\)\z},
-        input => sub {
-            my ($class, $value) = @_;
-
-            if ($value !~ m{\Aperl\(((?:\w+::)*\w+)\)\z})
-            {
-                die "Improper value for rpm_colon";
-            }
-
-            return $class->_calc_components_from_string(
-                {format => 'colon', value => $1}
-            );
-        },
-        format => sub {
-             my ($self) = @_;
-
-             return 'perl(' . $self->format_as('colon') . ')';
-        },
-    },
-    {
-        name => 'colon',
-        regex => qr{\A$colon_re\z},
-        input => sub {
-            my ($class, $value) = @_;
-            return [split(/::/, $value, -1)];
-        },
-        format => sub {
-            my ($self) = @_;
-
-            return join('::', @{$self->_components()});
-        },
-    },
-    {
-        name => 'dash',
-        regex => qr{\A$dash_re\z},
-        input => sub {
-            my ($class, $value) = @_;
-            return [split(/-/, $value, -1)];
-        },
-        format => sub {
-            my ($self) = @_;
-
-            return join('-', @{$self->_components()});
-        },
-    },
-    {
-        name => 'unix',
-        regex => qr{\A(?:\w+/)*\w+\.pm\z},
-        input => sub {
-            my ($class, $value) = @_;
-
-            if ($value !~ s{\.pm\z}{})
-            {
-                die "Cannot find a .pm suffix in the 'unix' format.";
-            }
-
-            return [split(m{/}, $value, -1)];
-        },
-        format => sub {
-            my ($self) = @_;
-
-            return join('/', @{$self->_components()}) . '.pm';
-        },
-    },
-    {
-        name => 'debian',
-        format => sub {
-            my ($self) = @_;
-
-            return 'lib' . lc($self->format_as('dash')) . '-perl';
-        },
-    },
-);
-
-my %formats = (map { $_->{name} => $_ } @formats_by_priority);
-
-sub _calc_components_from_string
-{
-    my ($class, $args) = @_;
-
-    my $format = $args->{format};
-    my $value = $args->{value};
-
-    if (exists($formats{$format}))
-    {
-        if (my $handler = $formats{$format}->{'input'})
-        {
-            return $class->$handler($value);
-        }
-        else
-        {
-            die "Format $format is output-only!";
-        }
-    }
-    else
-    {
-        die "Unknown format '$format'!";
-    }
-}
-
-sub from
-{
-    my ($class, $args) = @_;
-
-    my $format = $args->{format};
-    my $value = $args->{value};
-
-    return $class->_new(
-        {
-            _components => $class->_calc_components_from_string($args)
-        }
-    );
-}
-
 =head2 my $array_ref = $module->get_components_list()
 
 Returns the components list of the module as an array reference. For
 example for the module C<One::Two::Three> it would be
 C<["One", "Two", "Three"]>.
 
-=cut
-
-sub get_components_list
-{
-    my $self = shift;
-
-    return [ @{$self->_components()} ];
-}
-
 =head2 $module->format_as($format)
 
 Format the module in the given format. See from() for a list.
 
-=cut
-
-sub format_as
-{
-    my ($self, $format) = @_;
-
-    if (exists($formats{$format}))
-    {
-        my $handler = $formats{$format}->{'format'};
-        return $self->$handler();
-    }
-    else
-    {
-        die "Unknown format '$format';";
-    }
-
-    return;
-}
-
 =head2 my $clone = $module->clone()
 
 Duplicates the object.
 
-=cut
-
-sub clone
-{
-    my $self = shift;
-
-    return ref($self)->from_components(
-        {components => $self->get_components_list() }
-    );
-}
-
 =head2 my $bool = $module->is_sane();
 
 Returns a boolean depending on if the component of the module do not contain
 any funny character (only alphanumeric characters and underscore.).
 
-=cut
-
-sub _all
-{
-    my ($cb, $l) = @_;
-
-    foreach (@$l)
-    {
-        if (not $cb->($_))
-        {
-            return;
-        }
-    }
-
-    return 1;
-}
-
-sub is_sane
-{
-    my $self = shift;
-
-    return _all( sub { m{\A\w+\z}; }, $self->_components());
-}
-
 =head2 my $module = Module::Format::Module->from_guess({ value => $string});
 
 Initialises a module object from a string while trying to guess its format.
@@ -397,38 +427,6 @@ It accepts a hash-ref with the following keys: C<'value'> that points to the
 string to serve as an input, and an optional C<'format_ref'> that will give
 the format that was decided upon.
 
-=cut
-
-sub from_guess
-{
-    my ($class, $args) = @_;
-
-    my $dummy_format_string;
-
-    my $string = $args->{value};
-    my $out_format_ref = ($args->{format_ref} || (\$dummy_format_string));
-
-    # TODO : After the previous line the indentation in vim is reset to the
-    # first column.
-
-    foreach my $format_record (@formats_by_priority)
-    {
-        if (my $regex = $format_record->{regex})
-        {
-            if ($string =~ $regex)
-            {
-                my $format_id = $format_record->{name};
-
-                ${$out_format_ref} = $format_id;
-
-                return $class->from({value => $string, format => $format_id,});
-            }
-        }
-    }
-
-    die "Could not guess the format of the value '$string'!";
-}
-
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
@@ -439,9 +437,6 @@ Please report any bugs or feature requests to C<bug-module-format at rt.cpan.org
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-Format>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -468,7 +463,6 @@ L<http://cpanratings.perl.org/d/Module-Format>
 
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2010 Shlomi Fish.
@@ -497,7 +491,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Module-Format/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Module::Format::Module
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Module-Format>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Module-Format>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-Format>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Module-Format>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Module-Format>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Module-Format>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/M/Module-Format>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Module-Format>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Module::Format>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-module-format at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Module-Format>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/perl-Module-Format>
+
+  git clone git://github.com/shlomif/perl-Module-Format.git
 
 =cut
-
-1; # End of Module::Format::Module
